"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../utils/constants");
const term = require('terminal-kit').terminal;
const chalk = require("chalk");
const figures = require("figures");
const _ = require("lodash");
const init_1 = require("./init");
const file_1 = require("../utils/file");
const debug = require('debug')('graphcool');
const INSTAGRAM_STARTER = 0;
const BLANK_PROJECT = 1;
exports.default = (props, env) => __awaiter(this, void 0, void 0, function* () {
    const { out, resolver } = env;
    const schemaFiles = resolver.schemaFiles('.');
    const projectFiles = resolver.projectFiles('.');
    const options = [
        [`${chalk.bold('Quickstart')}`, `Sets up an Instagram example project to explore how things work.`, ''],
        [`${chalk.bold('New blank project')}`, `Creates a new Graphcool project from scratch.`, ''],
        ...schemaFiles.map(f => [`${chalk.bold('From local schema ./' + f)}`, 'Creates a new Graphcool project based on the local schema.', '']),
        ...projectFiles.map(f => [`${chalk.bold('Copy existing project ./' + f)}`, 'Creates a clone of an existing Graphcool project.', '']),
    ];
    term.saveCursor();
    out.write(constants_1.howDoYouWantToGetStarted());
    term.grabInput();
    // term.hideCursor()
    let currentIndex = INSTAGRAM_STARTER; // 0
    render(options, currentIndex);
    yield new Promise(resolve => {
        term.on('key', (name) => __awaiter(this, void 0, void 0, function* () {
            currentIndex = yield handleKeyEvent(name, currentIndex, options, props, env, resolve);
        }));
    });
});
function handleKeyEvent(name, currentIndex, options, props, env, callback) {
    return __awaiter(this, void 0, void 0, function* () {
        switch (name) {
            case 'DOWN': {
                currentIndex = (currentIndex + 1) % options.length;
                rerender(options, currentIndex);
                break;
            }
            case 'UP': {
                currentIndex = (currentIndex + options.length - 1) % options.length;
                rerender(options, currentIndex);
                break;
            }
            case 'ENTER': {
                yield handleSelect(currentIndex, props, env);
                callback();
                break;
            }
            case 'CTRL_C': {
                term.restoreCursor();
                term.eraseDisplayBelow();
                term.hideCursor(false);
                env.out.write('\n');
                process.exit();
            }
            default: {
                break;
            }
        }
        return currentIndex;
    });
}
function handleSelect(selectedIndex, props, env) {
    return __awaiter(this, void 0, void 0, function* () {
        term.restoreCursor();
        term.eraseDisplayBelow();
        term.hideCursor(false);
        env.out.write('\n');
        if (selectedIndex === INSTAGRAM_STARTER || selectedIndex === BLANK_PROJECT) {
            term.grabInput(false);
            yield props.checkAuth();
        }
        switch (selectedIndex) {
            case INSTAGRAM_STARTER: {
                const schemaUrl = constants_1.instagramExampleSchemaUrl;
                const initProps = getPropsForInit(props);
                yield init_1.default(Object.assign({}, initProps, { schemaUrl }), env);
                break;
            }
            case BLANK_PROJECT: {
                const schemaUrl = constants_1.sampleSchemaURL;
                const initProps = getPropsForInit(props);
                yield init_1.default(Object.assign({}, initProps, { schemaUrl }), env);
                break;
            }
            default: {
                term.grabInput(false);
                const schemaFiles = env.resolver.schemaFiles('.');
                const projectFiles = env.resolver.projectFiles('.');
                const previousOptions = 2;
                if (selectedIndex >= previousOptions && selectedIndex < previousOptions + schemaFiles.length) {
                    const schemaFileIndex = selectedIndex - previousOptions;
                    const localSchemaFile = schemaFiles[schemaFileIndex];
                    const initProps = getPropsForInit(props);
                    yield init_1.default(Object.assign({}, initProps, { localSchemaFile }), env);
                }
                else if (selectedIndex >= previousOptions + schemaFiles.length && selectedIndex < previousOptions + schemaFiles.length + projectFiles.length) {
                    const projectFileIndex = selectedIndex - schemaFiles.length - previousOptions;
                    const projectFile = projectFiles[projectFileIndex];
                    const copyProjectId = file_1.readProjectIdFromProjectFile(env.resolver, projectFile);
                    const initProps = getPropsForInit(props);
                    const initProps2 = Object.assign({}, initProps, { copyProjectId, projectFile });
                    console.log(`Call init with props: ${JSON.stringify(initProps2)}`);
                    yield init_1.default(initProps2, env);
                }
                break;
            }
        }
    });
}
function getPropsForInit(props) {
    return {
        name: props.name,
        alias: props.alias,
        region: props.region,
        outputPath: props.outputPath
    };
}
function rerender(options, currentIndex) {
    clear(options);
    render(options, currentIndex);
}
function clear(options) {
    const lineCount = _.flatten(options).length - 1;
    term.up(lineCount);
    term.left(10000);
    term.eraseDisplayBelow();
}
function render(options, currentIndex) {
    const lines = _.chain(options)
        .map((ls, optionIndex) => ls.map((l, lineIndex) => (lineIndex === 0 && optionIndex === currentIndex) ? `  ${chalk.blue(figures.pointer)} ${l}` : `    ${l}`))
        .flatten()
        .join('\n');
    term(lines, currentIndex);
}
//# sourceMappingURL=interactiveInit.js.map